@@ -94,15 +94,15 @@ def sagemaker_processing_output_args(parser: argparse.ArgumentParser, outputs=No
                 help=OUTPUT_S3_HELP.format(k=k, v=s3_default))
 
 
-def sagemaker_processing_module_args(parser: argparse.ArgumentParser, modules=None,
+def sagemaker_processing_module_args(parser: argparse.ArgumentParser, dependencies=None,
                                      module_mount=MODULE_MOUNT):
-    if modules is None:
-        modules = {}
+    if dependencies is None:
+        dependencies = {}
     parser.add_argument(
         '--sagemaker-module-mount',
         default=module_mount,
         help=MODULE_MOUNT_HELP.format(module_mount))
-    for k, v in modules.items():
+    for k, v in dependencies.items():
         varname = "module_{}".format(k)
         flag = variable_to_argparse(varname)
         parser.add_argument(
@@ -113,35 +113,140 @@ def sagemaker_processing_module_args(parser: argparse.ArgumentParser, modules=No
 
 def sagemaker_processing_args(
     parser: argparse.ArgumentParser,
+    script,
     run=False,
+    wait=True,
     profile=PROFILE,
     role=PROCESSING_ROLE,
     image=PROCESSING_IMAGE,
     instance=PROCESSING_INSTANCE,
     inputs=None,
     outputs=None,
-    modules=None,
+    dependencies=None,
     input_mount=INPUT_MOUNT,
     output_mount=OUTPUT_MOUNT,
     module_mount=MODULE_MOUNT,
-    job_name=PROCESSING_JOB_NAME,
+    base_job_name=PROCESSING_JOB_NAME,
+    job_name='',
     runtime_seconds=PROCESSING_RUNTIME_SECONDS,
     volume_size=PROCESSING_VOLUME_SIZE,
     python='python3',
     requirements=None,
     configuration_script=None,
+    configuration_command=None,
     additional_arguments=None,
     argparse_callback=None
 ):
+    r"""
+    Configure ``argparse.ArgumentParser`` for processing scripts.
+
+    Parameters
+    ----------
+    parser : argparse.ArgumentParser
+        Parser to configure
+    script : str
+        Path to script file to execute.
+        Set default for ``--sagemaker-script``
+    run : bool, optional
+        Run on SageMaker. 
+        Set default for ``--sagemaker-run``.
+    wait : bool, optional
+        Wait for SageMaker processing to complete. 
+        Set default for ``--sagemaker-wait``.
+    profile : str, optional
+        AWS profile to use for session. 
+        Set default for ``--sagemaker-profile``.
+    role : str, optional
+        AWS IAM role name to use for processing. Will be created if it does not exist. 
+        Set default for ``--sagemaker-role``.
+    image : str, optional
+        URI of ECR Docker image to use for processing. 
+        Set default for ``--sagemaker-image``.
+    instance : str, optional
+        Type of instance to use for processing (e.g., ``ml.t3.medium``). 
+        Set default for ``--sagemaker-instance``.
+    inputs : dict(str,str), optional
+        Dictionary of input arguments.
+        For eack key and value, create an argument ``--key`` that defaults to value.
+
+        * Running locally, input arguments are unmodified.
+        * Running remotely, inputs are set to appropriate SageMaker mount points. Local inputs are uploaded automatically.
+    outputs : dict(str, tuple(str))
+        Dictionary of output arguments.
+        For eack key:
+
+            * Create an argument ``--key`` that defaults to value[0]. This controls an output path.
+            * Create an argument ``--key-s3`` that defaults to value[1]. This controls where output is stored on S3.
+              * Set to ``default`` to automatically create an output path based on the job name
+              * Set to an S3 URL to store output at a specific location on S3
+    dependencies : dict(str, str)
+        Dictionary of modules.
+        For eack key and value, create an argument ``--module-key`` that defaults to value. 
+        This controls the path of a dependency of your code.
+        The files at the given path will be uploaded to S3, downloaded to SageMaker, and put on PYTHONPATH.    
+    input_mount : str, optional
+        Local path on SageMaker container where inputs are downloaded.
+        Set default for ``--sagemaker-input-mount``.
+    output_mount : str, optional
+        Local path on SageMaker container where outputs are written before upload.
+        Set default for ``--sagemaker-output-mount``.
+    module_mount : str, optional
+        Local path on SageMaker container where source code is downloaded. Mount point is put on PYTHONPATH.
+        Set default for ``--sagemaker-module-mount``.
+    base_job_name : str, optional
+        Job name will be generated from ``base_job_name`` and a timestamp if ``job_name`` is not provided.
+        Set default for ``--sagemaker-base-job-name``.
+    job_name : str, optional
+        Job name is used for tracking and organization. 
+        Generated from ``base_job_name`` if not provided.
+        Use ``base_job_name`` and leave ``job_name`` blank for most use-cases.
+        Set default for ``--sagemaker-job-name``.
+    runtime_seconds: int, optional
+        Maximum in seconds before killing job.
+        Set default for ``--sagemaker-runtime-seconds``.
+    volume_size: int, optional
+        Volume size in GB.
+        Set default for ``--sagemaker-volume-size``.
+    python: str, optional
+        Pyton executable on container (default: ``python3``).
+        Set default for ``--sagemaker-python``.
+    requirements: str, optional
+        Set path to requirements file to upload and install with ``pip install -r``.
+        Set default for ``--sagemaker-requirements``.
+    configuration_script: str, optional
+        Set path to bash script to upload and source.
+        Set default for ``--sagemaker-configuration-script``.
+    configuration_command: str, optional
+        Set command to be run to configure container,
+        e.g. ``pip install mypackage && export MYVAR=MYVALUE``.
+        Set default for ``--sagemaker-configuration-command``.
+    additional_arguments: list, optional
+        List of tuple of positional args and keyword args for ``argparse.ArgumentParser.add_argument``.
+        Use to add additional arguments to the script.
+    argparse_callback: function, optional
+        Function accepting one argument ``parser:argparse.ArgumentParser`` that adds additional arguments.
+        Use to add additional arguments to the script.
+    """
     if additional_arguments is None:
         additional_arguments = []
     sagemaker_profile_args(parser=parser, profile=profile)
     bool_argument(parser, '--sagemaker-run', default=run,
                   help="Run processing on SageMaker (yes/no default={})".format(run))
+    bool_argument(parser, '--sagemaker-wait', default=wait,
+                  help="Wait for SageMaker processing to complete and tail logs (yes/no default={})".format(wait))
+    parser.add_argument('--sagemaker-script', default=script,
+                        help='Python script to execute (default: [{}])'.format(script))
     parser.add_argument('--sagemaker-python', default=python,
                         help='Python executable to use in container (default: [{}])'.format(python))
     parser.add_argument('--sagemaker-job-name', default=job_name,
-                        help='Job name for SageMaker processing (default: [{}])'.format(job_name))
+                        help='Job name for SageMaker processing. '
+                        'If not provided, will be generated from base job name. '
+                        'Leave blank for most use-cases. '
+                        '(default: [{}])'.format(job_name))
+    parser.add_argument('--sagemaker-base-job-name', default=base_job_name,
+                        help='Base job name for SageMaker processing .'
+                        'Job name will be generated from the base name and a timestamp '
+                        '(default: [{}])'.format(base_job_name))
     parser.add_argument('--sagemaker-runtime-seconds', default=runtime_seconds,
                         help='SageMaker maximum runtime in seconds (default: [{}])'.format(runtime_seconds))
     parser.add_argument('--sagemaker-role', default=role,
@@ -150,6 +255,10 @@ def sagemaker_processing_args(
                         help='Requirements file to install on SageMaker (default: [{}])'.format(requirements))
     parser.add_argument('--sagemaker-configuration-script', default=configuration_script,
                         help='Bash configuration script to source on SageMaker (default: [{}])'.format(configuration_script))
+    parser.add_argument('--sagemaker-configuration-command', default=configuration_command,
+                        help='Bash command to run on SageMaker for configuration '
+                        '(e.g., ``pip install aws_sagemaker_remote && export MYVAR=MYVALUE``) '
+                        '(default: [{}])'.format(configuration_command))
     parser.add_argument('--sagemaker-image', default=image,
                         help='AWS ECR image URI of Docker image to run SageMaker processing (default: [{}])'.format(image))
     parser.add_argument('--sagemaker-instance', default=instance,
@@ -168,7 +277,7 @@ def sagemaker_processing_args(
     )
     sagemaker_processing_module_args(
         parser=parser,
-        modules=modules,
+        dependencies=dependencies,
         module_mount=module_mount
     )
     for args, kwargs in additional_arguments:
@@ -176,35 +285,26 @@ def sagemaker_processing_args(
     if argparse_callback:
         argparse_callback(parser)
     return SageMakerProcessingConfig(
-        modules=modules,
+        dependencies=dependencies,
         inputs=inputs,
         outputs=outputs
     )
 
-    """
-    if channels is None:
-        channels = DEFAULT_CHANNELS
-    if device is None:
-        device = "cpu" if not torch.cuda.is_available() else "cuda"
-    output_dir = os.environ.get('SM_OUTPUT_DIR', output_dir)
-    parser.add_argument("--device", type=str, default=device,
-                        help="device to use (default: {})".format(device))
-    parser.add_argument('--output-dir', type=str,
-                        default=output_dir,
-                        help='directory for checkpoints, logs, images, or other output files (default: "{}")'.format(output_dir))
-    for channel, default in channels.items():
-        key = 'SM_CHANNEL_{}'.format(channel.upper())
-        if key in os.environ:
-            default = os.environ[key]
-        else:
-            default = os.path.abspath(os.path.join(__file__, default))
-        parser.add_argument('--{}'.format(channel), type=str,  default=default,
-                            help="input directory for [{}] channel".format(channel))
-    """
 
-
-def sagemaker_training_args(
-    parser: argparse.ArgumentParser
-):
-    parser.add_argument("--sagemaker-run", default=False,
-                        help="Run training on SageMaker (yes/no default=no)")
+def sagemaker_processing_parser_for_docs():
+    parser = argparse.ArgumentParser()
+    script = 'script.py'
+    sagemaker_processing_args(
+        parser=parser,
+        script=script,
+        inputs={
+            'input': '/path/to/input'
+        },
+        outputs={
+            'output': ('/path/to/output', 'default')
+        },
+        dependencies={
+            'my_module': '/path/to/my_module'
+        }
+    )
+    return parser
