@@ -18,7 +18,8 @@ from .args import sagemaker_processing_args
 PROCESSING_SCRIPT = os.path.abspath(os.path.join(__file__, '../processing.sh'))
 
 
-def sagemaker_processing_run(args, config, script):
+def sagemaker_processing_run(args, config):
+    script = args.sagemaker_script
     script = os.path.abspath(script)
     script = script.replace("\\", "/")
 
@@ -29,18 +30,19 @@ def sagemaker_processing_run(args, config, script):
     outputs = {
         k: (getattr(args, k), getattr(args, "{}_s3".format(k))) for k in config.outputs.keys()
     }
-    modules = {
-        k: getattr(args, "module_{}".format(k)) for k in config.modules.keys()
+    dependencies = {
+        k: getattr(args, "module_{}".format(k)) for k in config.dependencies.keys()
     }
     process(
         inputs=inputs,
         outputs=outputs,
-        modules=modules,
+        dependencies=dependencies,
         session=session,
         role=args.sagemaker_role,
         script=script,
         image=args.sagemaker_image,
         instance=args.sagemaker_instance,
+        base_job_name=args.sagemaker_base_job_name,
         job_name=args.sagemaker_job_name,
         volume_size=args.sagemaker_volume_size,
         python=args.sagemaker_python,
@@ -53,7 +55,8 @@ def sagemaker_processing_run(args, config, script):
             args, 'sagemaker_module_mount') else None,
         arguments=make_arguments(args=args, config=config),
         requirements=args.sagemaker_requirements,
-        configuration_script=args.sagemaker_configuration_script
+        configuration_script=args.sagemaker_configuration_script,
+        configuration_command=args.sagemaker_configuration_command
     )
 
 
@@ -63,7 +66,7 @@ def make_arguments(args, config: SageMakerProcessingConfig):
     to_del.extend(config.inputs.keys())
     to_del.extend(config.outputs.keys())
     to_del.extend("{}_s3" for k in config.outputs.keys())
-    to_del.extend("module_{}".format(k) for k in config.modules.keys())
+    to_del.extend("module_{}".format(k) for k in config.dependencies.keys())
     for k in to_del:
         if k in vargs:
             del vargs[k]
@@ -90,10 +93,12 @@ def process(
     # script_source,
     inputs=None,
     outputs=None,
-    modules=None,
+    dependencies=None,
     requirements=None,
     configuration_script=None,
-    job_name=PROCESSING_JOB_NAME,
+    configuration_command=None,
+    base_job_name=PROCESSING_JOB_NAME,
+    job_name=None,
     image=PROCESSING_IMAGE,
     instance=PROCESSING_INSTANCE,
     volume_size=30,
@@ -112,8 +117,8 @@ def process(
         inputs = {}
     if outputs is None:
         outputs = {}
-    if modules is None:
-        modules = {}
+    if dependencies is None:
+        dependencies = {}
     # if module_mount is not None and len(module_mount)> 0:
     #    command = ["PYTHONPATH={module_mount};${{PYTHONPATH}}".format(module_mount=module_mount), "python3"]
     # else:
@@ -141,7 +146,7 @@ def process(
             # s3_data_distribution_type='FullyReplicated',
             # s3_compression_type='None'
         )
-        for name, source in modules.items()
+        for name, source in dependencies.items()
     ])
     script_remote = "{}/{}".format(module_mount, os.path.basename(script))
     processing_inputs.append(
@@ -186,6 +191,9 @@ def process(
             )
         )
 
+    if configuration_command and len(configuration_command) > 0:
+        env['AWS_SAGEMAKER_REMOTE_CONFIGURATION_COMMAND'] = configuration_command
+
     processor = ScriptProcessor(
         role,
         image_uri=image,
@@ -196,7 +204,7 @@ def process(
         # volume_kms_key=None,
         # output_kms_key=None,
         max_runtime_in_seconds=runtime_seconds,
-        base_job_name=job_name,
+        base_job_name=base_job_name,
         sagemaker_session=session,
         env=env,
         tags=[
@@ -206,7 +214,7 @@ def process(
             },
             {
                 "Key": "Name",
-                "Value": job_name
+                "Value": base_job_name
             }
         ]
         # network_config=None
@@ -227,12 +235,17 @@ def process(
         for name, dest in outputs.items()
     ]
     code = Path(PROCESSING_SCRIPT).as_uri()
+    if job_name is None or len(str(job_name).strip()) == 0:
+        job_name = None
+    else:
+        job_name = str(job_name).strip()
     processor.run(
         code=code,
         inputs=processing_inputs,
         outputs=processing_outputs,
         wait=wait,
         logs=logs,
+        job_name=job_name,
         arguments=arguments
     )
     return processor
